@@ -6,12 +6,14 @@ import logging
 import traceback
 
 from lesscode.db.redis.redis_helper import RedisHelper
-from tornado.options import options
+from tornado.options import options, define
 
 # 装饰器
 from lesscode.utils.JsonUtil import JSONEncoder
 
 
+
+
 def Cache(ex=3600 * 8, cache_key=None):
     def cache_func(func):
         # 默认key生成方法：str(item)
@@ -46,9 +48,9 @@ def deal_cache(func, ex, cache_key, *args, **params):
     return data
 
 
-def query_cache(cache_key):
+def query_cache(cache_key, conn_name=options.cache_conn):
     if options.cache_module:
-        data = RedisHelper("redis_con_1").sync_get(cache_key)
+        data = RedisHelper(conn_name).sync_get(cache_key)
         if data:
             value = json.loads(data)
             return value
@@ -59,9 +61,6 @@ def query_cache(cache_key):
 
 
 def format_insert_key(func_name, args, params):
-    if args and isinstance(args[0], object) and args[0].__class__.__name__ == func_name.split(".")[0]:
-        args = args[1:]
-
     str_insert_key = str(args)
     for k in params:
         if isinstance(params[k], dict):
@@ -76,9 +75,9 @@ def format_insert_key(func_name, args, params):
     return str_insert_key
 
 
-def insert_cache(data, ex, cache_key):
+def insert_cache(data, ex, cache_key, conn_name=options.cache_conn):
     if options.cache_module:
         try:
-            RedisHelper("redis_con_1").sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
+            RedisHelper(conn_name).sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
         except:
             logging.error(traceback.format_exc())
